@@ -504,7 +504,7 @@ def strip_comments(value):
         @xxx [03-21-2022 12:29:07]: documentation for strip_comments
     '''
 
-    value = _re.sub(r'--[^\n]*\n','',value,_re.MULTILINE)
+    value = _re.sub(r'--[^\n]*\n','',value)
     return value
 
 def strip_sql_quotes(sql):
